@@ -19,7 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, 
  * Boston, MA  02110-1301  USA
  */
-#include "db_interface_function.h" 
+#include "db_interface_function.h"
 
 /** response **/
 const char* db_response = "\
@@ -97,14 +97,25 @@ xmlDocPtr DB_SEND_REQUEST(xmlDocPtr ui_request)
 		xmlNodeSetContent(node_req, BAD_CAST DB_ID);
 	}
 
-	/** get data from gconf **/	
+	/** get data from gconf **/
+    gchar *g_conf_path = g_strconcat(DB_PATH_GCONF, DB_LIST_DRIVERS, NULL);
 	client = gconf_client_get_default ();
-	xml_conf = (xmlChar*)gconf_client_get_string (client, 
-					g_strconcat(DB_PATH_GCONF, DB_LIST_DRIVERS, NULL), NULL);
+	xml_conf = (xmlChar*)gconf_client_get_string (client, g_conf_path, NULL);
+    g_free(g_conf_path);
 
 	db_settings = xmlParseDoc(BAD_CAST xml_conf);
 	node_settings_root = xmlDocGetRootElement(db_settings);
 
+    /** if drivers list is null then ERROR! **/
+    if (node_settings_root == NULL || node_settings_root->children == NULL) {
+
+            db_request = xmlParseDoc(BAD_CAST db_message); 
+			db_request = db_generate_message(db_request, INFO_MESSAGE, 
+	                                         DB_INIT_ERROR_TEXT, 
+                                             DB_INIT_ERROR_CODE);
+            return db_request;  
+    }
+
 	/** rem all old targets **/
 	rem_targets(db_request);
 
@@ -117,7 +128,7 @@ xmlDocPtr DB_SEND_REQUEST(xmlDocPtr ui_request)
 			
 			add_target(db_request, xmlNodeGetContent(node_settings));
 		}
-	
+
 	}	
 
 
@@ -277,8 +288,8 @@ xmlDocPtr DB_SAVE_FRIENDS(xmlDocPtr drv_response)
 	xmlXPathObject* Obj = db_xpath(RESPONSE_TAG_XPATH, drv_response);	
 	xmlNodePtr node_set = Obj->nodesetval->nodeTab[0];
 	gchar* resp_class = (gchar*)xmlGetProp(node_set, BAD_CAST "class");
-	gchar* friends_id;
-	gchar* resp_xpath;
+	gchar* friends_id = NULL;
+	gchar* resp_xpath = NULL;
 	gint i;
 
 	/** if class FRIENDS, else error **/
@@ -321,7 +332,11 @@ xmlDocPtr DB_SAVE_FRIENDS(xmlDocPtr drv_response)
 
     xmlXPathFreeObject(Obj);
     xmlFreeDoc(drv_response);
-	
+    
+    g_free(resp_class);	
+    g_free(friends_id);
+    g_free(resp_xpath);
+
 	g_debug("DB_SAVE_FRIENDS: END");
 
 	return db_resp;
@@ -342,125 +357,130 @@ xmlDocPtr DB_GET_FRIENDS(xmlDocPtr request)
 	GSList* response_list;
 
 	response_list = get_contacts(FALSE);	
-	if (response_list != NULL) {
 
-		g_debug("db_get_profile response list isn't null!");
-		
-		gint i;
-		gint fr_from = 0;
-		gint fr_to = 0;
-		xmlChar* str = NULL;		
+        if (response_list != NULL) {
 
-		xmlNodePtr node_set;
-		xmlDocPtr fr_resp = xmlParseDoc(BAD_CAST "<Params><array name=\"contacts\"/></Params>");
-		xmlNodePtr fr_resp_root = xmlDocGetRootElement(fr_resp);
-		
-		xmlNodePtr fr_resp_node = fr_resp_root->children;
+            g_debug("db_get_profile response list isn't null!");
 
-		guint fr_count = g_slist_length(response_list);		
+            gint i;
+            gint fr_from = 0;
+            gint fr_to = 0;
+            xmlChar* str = NULL;
 
-		xmlSetProp(fr_resp_node, BAD_CAST "friendsQuantity", BAD_CAST g_strdup_printf("%d", fr_count));
+            xmlNodePtr node_set;
+            xmlDocPtr fr_resp = xmlParseDoc(BAD_CAST "<Params><array name=\"contacts\"/></Params>");
+            xmlNodePtr fr_resp_root = xmlDocGetRootElement(fr_resp);
 
-		/** get parametrs in Params node**/
-		xmlXPathObject* Obj = db_xpath(REQUEST_PARAMS_TAG_XPATH, request);
-		if (Obj->nodesetval->nodeNr != 0) {
-			node_set = Obj->nodesetval->nodeTab[0];
+            xmlNodePtr fr_resp_node = fr_resp_root->children;
 
-			/** get From **/			
-			str = xmlGetProp(node_set,BAD_CAST "From");
-			if (str != NULL) {
-				fr_from = atoi((char*)str);
-			} else {
-				fr_from = 0;			
-			}
-			
-			/** get TO **/ 
-			str = xmlGetProp(node_set,BAD_CAST "To");
-			if (str != NULL) {
-				fr_to = atoi((char*)str);
-			} else {
-				fr_to = 10;			
-			} 
+            guint fr_count = g_slist_length(response_list);
 
-			/** type of sort list if NULL then no sort **/
-			str = xmlGetProp(node_set,BAD_CAST "Sort");
-			if (str != NULL) {
-			
-				if (strcmp((char*)str,(char*)"asc") == 0) {
-					response_list = g_slist_sort(response_list, (GCompareFunc)db_sort_asc);
-				} 
-				if (strcmp((char*)str,(char*)"desc") == 0) {
-					response_list = g_slist_sort(response_list, (GCompareFunc)db_sort_desc);
-				}
-	
-			}
+            xmlSetProp(fr_resp_node, BAD_CAST "friendsQuantity", BAD_CAST g_strdup_printf("%d", fr_count));
 
-			/** filter if null or empty then no filter **/
-			str = xmlGetProp(node_set,BAD_CAST "Filter");
-			if (str != NULL && strlen((char*)str) > 0) {
-		
-				//GSList* find_element;
-				GSList* list_element;			
-	
-				fr_to = 1;	
-				fr_from = 0;			
-			
-				list_element = response_list;
-				response_list = NULL;				
+            /** get parametrs in Params node**/
+            xmlXPathObject* Obj = db_xpath(REQUEST_PARAMS_TAG_XPATH, request);
+            if (Obj->nodesetval->nodeNr != 0) {
+                    node_set = Obj->nodesetval->nodeTab[0];
 
-				while (list_element != NULL) {
-				
-					if (db_friends_find( (gpointer)list_element->data, (gpointer)str ) == 0) {
-						response_list = g_slist_append(response_list, list_element->data);
-						fr_to++;
-					}
-					list_element = list_element->next;		
-				}
+                    /** get From **/
+                    str = xmlGetProp(node_set,BAD_CAST "From");
+                    if (str != NULL) {
+                            fr_from = atoi((char*)str);
+                    } else {
+                            fr_from = 0;
+                    }
 
-				xmlSetProp(fr_resp_node, BAD_CAST "friendsQuantity", BAD_CAST g_strdup_printf("%d", fr_to - 1));
-				xmlSetProp(fr_resp_node, BAD_CAST "Filter", BAD_CAST str);						
-			} // if (str) > 0
-		}// if req ok
+                    /** get TO **/
+                    str = xmlGetProp(node_set,BAD_CAST "To");
+                    if (str != NULL) {
+                            fr_to = atoi((char*)str);
+                    } else {
+                            fr_to = 10;
+                    }
+                    xmlFree(str);
 
-		/** error **/
-		if (response_list == NULL ) {
-			db_resp = xmlParseDoc(BAD_CAST db_message); 
-			db_resp = db_generate_message(db_resp, ERROR_MESSAGE, 
-										  DB_GET_ERROR_FRIENDS_TEXT, 
-										  DB_GET_ERROR_FRIENDS_CODE);
-			return db_resp;		
-		}
+                    /** type of sort list if NULL then no sort **/
+                    str = xmlGetProp(node_set,BAD_CAST "Sort");
+                    if (str != NULL) {
 
-		GSList* list = g_slist_nth(response_list, fr_from);
+                            if (strcmp((char*)str,(char*)"asc") == 0) {
+                                    response_list = g_slist_sort(response_list, (GCompareFunc)db_sort_asc);
+                            }
+                            if (strcmp((char*)str,(char*)"desc") == 0) {
+                                    response_list = g_slist_sort(response_list, (GCompareFunc)db_sort_desc);
+                            }
+                    }
+                    xmlFree(str);
 
-		for (i=fr_from; i<fr_to; i++) {
+                    /** filter if null or empty then no filter **/
+                    str = xmlGetProp(node_set,BAD_CAST "Filter");
+                    if (str != NULL && strlen((char*)str) > 0) {
 
-			node_set = xmlDocGetRootElement((xmlDocPtr)list->data);
-			xmlUnlinkNode(node_set);
-			xmlAddChild(fr_resp_node, node_set);
-			
-			if (list->next == NULL) {
-				break;
-			}
+                            //GSList* find_element;
+                            GSList* list_element;
 
-			list = list->next;
-			
-		}
+                            fr_to = 1;
+                            fr_from = 0;
 
-		db_resp = db_generate_response(struct_response, fr_resp_root,
-									   CLASS_FRIENDS, GET_FRIENDS);	
+                            list_element = response_list;
+                            response_list = NULL;
 
-	    xmlXPathFreeObject(Obj);	
+                            while (list_element != NULL) {
 
-	} else {
-		db_resp = xmlParseDoc(BAD_CAST db_message); 
-		db_resp = db_generate_message(db_resp, ERROR_MESSAGE, 
-									  DB_GET_ERROR_FRIENDS_TEXT, 
-									  DB_GET_ERROR_FRIENDS_CODE);
-	}
+                                    if (db_friends_find( (gpointer)list_element->data, (gpointer)str ) == 0) {
+                                            response_list = g_slist_append(response_list, list_element->data);
+                                            fr_to++;
+                                    }
+                                    list_element = list_element->next;
+                            }
 
-	g_debug("db_get_profile: END");	
-	return db_resp;
+                            xmlSetProp(fr_resp_node, BAD_CAST "friendsQuantity", BAD_CAST g_strdup_printf("%d", fr_to - 1));
+                            xmlSetProp(fr_resp_node, BAD_CAST "Filter", BAD_CAST str);
+                    } // if (str) > 0
+                    xmlFree(str);
+
+        }// if req ok
+
+        /** error **/
+        if (response_list == NULL ) {
+                db_resp = xmlParseDoc(BAD_CAST db_message);
+                db_resp = db_generate_message(db_resp, ERROR_MESSAGE,
+                                                                  DB_GET_ERROR_FRIENDS_TEXT,
+                                                                  DB_GET_ERROR_FRIENDS_CODE);
+            return db_resp;
+        }
+
+        GSList* list = g_slist_nth(response_list, fr_from);
+
+        for (i=fr_from; i<fr_to; i++) {
+
+            node_set = xmlDocGetRootElement((xmlDocPtr)list->data);
+            xmlUnlinkNode(node_set);
+            xmlAddChild(fr_resp_node, node_set);
+
+            if (list->next == NULL) {
+                    break;
+            }
+
+            xmlDocSetRootElement((xmlDocPtr)list->data, NULL);
+            xmlFreeDoc((xmlDocPtr)list->data);
+            list = list->next;
+        }
+
+        db_resp = db_generate_response(struct_response, fr_resp_root,
+                                                                   CLASS_FRIENDS, GET_FRIENDS);
+        xmlXPathFreeObject(Obj);
+
+
+    } else {
+            db_resp = xmlParseDoc(BAD_CAST db_message);
+            db_resp = db_generate_message(db_resp, ERROR_MESSAGE,
+                                                              DB_GET_ERROR_FRIENDS_TEXT,
+                                                              DB_GET_ERROR_FRIENDS_CODE);
+    }
+
+    g_debug("db_get_profile: END");
+    return db_resp;
 }
 
 /**
@@ -671,7 +691,10 @@ xmlDocPtr DB_GET_INBOX_MESSAGES(xmlDocPtr ui_request)
        } else {
              messages_from = 0;			
        }
-       xmlSetProp(node_root, BAD_CAST "From", BAD_CAST g_strdup_printf("%d", messages_from));		
+        
+       char * node_prop =  g_strdup_printf("%d", messages_from);
+       xmlSetProp(node_root, BAD_CAST "From", BAD_CAST node_prop);
+       free(node_prop);		
 
 	/** get TO **/ 
 	str = (gchar*)xmlGetProp(node_set,BAD_CAST "To");
@@ -680,8 +703,9 @@ xmlDocPtr DB_GET_INBOX_MESSAGES(xmlDocPtr ui_request)
 	} else {
 		messages_to = 10;			
 	} 
-        xmlSetProp(node_root, BAD_CAST "To", BAD_CAST g_strdup_printf("%d", messages_to));
-
+        char *message_to_prop = g_strdup_printf("%d", messages_to);
+        xmlSetProp(node_root, BAD_CAST "To", BAD_CAST message_to_prop);
+        g_free(message_to_prop);
    }
 
 	if (response_list == NULL ) {
@@ -696,21 +720,25 @@ xmlDocPtr DB_GET_INBOX_MESSAGES(xmlDocPtr ui_request)
 
 	for (i=messages_from; i<messages_to; i++) {
 
-		node_set = xmlDocGetRootElement((xmlDocPtr)list->data);
-		xmlUnlinkNode(node_set);
-		xmlAddChild(node_array, node_set);
+            node_set = xmlDocGetRootElement((xmlDocPtr)list->data);
+            xmlUnlinkNode(node_set);
+            xmlAddChild(node_array, node_set);
 
-		if (list->next == NULL) {
-			break;
-		}
+            if (list->next == NULL) {
+                    break;
+            }
 
-		list = list->next;
+            xmlDocSetRootElement((xmlDocPtr)list->data, NULL);
+            xmlFreeDoc((xmlDocPtr)list->data);
+
+            list = list->next;
 
 	}
 
 	db_resp = db_generate_response(struct_resp, node_root,
 								   CLASS_BOX_MESSAGE, GET_INBOX_MESSAGES);
     xmlFreeDoc(ui_request);
+    g_free(str);
     xmlXPathFreeObject(Obj);
 	return db_resp;
 }
@@ -733,8 +761,8 @@ xmlDocPtr GET_NEW_MESSAGES_FUNC(xmlDocPtr drv_response)
     int i;
     int message_count = Obj->nodesetval->nodeNr;
 
-    g_debug("message count !!!! %d", message_count);
-    xmlDocDump(stdout, drv_response);    
+    //g_debug("message count !!!! %d", message_count);
+    //xmlDocDump(stdout, drv_response);    
     //sleep(10);
 
 	for(i = 0; i<message_count; i++) {
@@ -789,11 +817,16 @@ static xmlDocPtr db_generate_response(xmlDocPtr response, xmlNodePtr resp_params
 	xmlNodePtr node;
 	xmlXPathObject *Obj;
 
+
 	/** get request node and set class and function**/
 	Obj = db_xpath(RESPONSE_TAG_XPATH, response);
 	//xmlDocDump(stdout, response);	
 
-
+        if (Obj == NULL || response == NULL) {
+            g_debug("obj is null!");
+            return 0;
+        }
+        
 	if (Obj->nodesetval->nodeNr != 0) {
 
 		node = Obj->nodesetval->nodeTab[0];
@@ -805,11 +838,13 @@ static xmlDocPtr db_generate_response(xmlDocPtr response, xmlNodePtr resp_params
 		
 		/** add response **/
 		xmlAddChild(node, resp_params);
-	}
+                g_debug("1111");
+                g_debug("\nHruuuuuuuuuuuuu!\, %s ", xmlNodeGetContent(node));
+        }
 
-    xmlXPathFreeObject(Obj);
-
-	return response;
+        xmlXPathFreeObject(Obj);
+	g_debug("db_generate_response: END");
+        return response;
 }
 
 
@@ -944,28 +979,27 @@ static gint db_sort_asc(gpointer a, gpointer b)
  */
 static gint db_sort_time(gpointer a, gpointer b)
 {
-    g_debug("g_sort_time");
 
-	xmlDocPtr doc_a = (xmlDocPtr)a;
-	xmlDocPtr doc_b = (xmlDocPtr)b;
-	
-	xmlNodePtr node_a = NULL;
-	xmlNodePtr node_b = NULL;	
+    xmlDocPtr doc_a = (xmlDocPtr)a;
+    xmlDocPtr doc_b = (xmlDocPtr)b;
+
+    xmlNodePtr node_a = NULL;
+    xmlNodePtr node_b = NULL;
 
 
-	xmlXPathObject *Obj = db_xpath("//struct/date[@name='Time']", doc_a);
+    xmlXPathObject *Obj = db_xpath("//struct/date[@name='Time']", doc_a);
 
-	if (Obj->nodesetval->nodeNr > 0) {
-		node_a = Obj->nodesetval->nodeTab[0];
-	}
+    if (Obj->nodesetval->nodeNr > 0) {
+            node_a = Obj->nodesetval->nodeTab[0];
+    }
 
     xmlXPathFreeObject(Obj);
 
-	Obj = db_xpath("//struct/date[@name='Time']", doc_b);
+    Obj = db_xpath("//struct/date[@name='Time']", doc_b);
 
-	if (Obj->nodesetval->nodeNr > 0) {
-		node_b = Obj->nodesetval->nodeTab[0];
-	}
+    if (Obj->nodesetval->nodeNr > 0) {
+            node_b = Obj->nodesetval->nodeTab[0];
+    }
 
     xmlChar* cont_a = xmlNodeGetContent(node_a);
     xmlChar* cont_b = xmlNodeGetContent(node_b);
@@ -976,7 +1010,7 @@ static gint db_sort_time(gpointer a, gpointer b)
     xmlFree(cont_b);
 
     xmlXPathFreeObject(Obj);
-	return icont_count;
+    return icont_count;
 
 } 
 
