@@ -348,7 +348,6 @@ gint load_binary_data_to_doc(const gchar* schema_name, xmlDocPtr doc)
                                   BINARY_DIR_NAME, G_DIR_SEPARATOR_S, NULL);
     
    
-    
     gchar* query = build_binary_nodes_select_query();
     xmlChar* ns = BAD_CAST cm_get_namespaces_key(schema_name);
     DB_PDEBUG(3, "query = %s", query);      
@@ -389,6 +388,7 @@ gint load_binary_data_to_doc(const gchar* schema_name, xmlDocPtr doc)
     xmlFree(ns);
     g_free(tmp_path);
     g_free(db_path);                     
+    g_free(query);
     
     return 0;             
 }
@@ -1376,13 +1376,19 @@ gint db_remove_node_by_id(const gchar* schema_name ,const gchar* id)
             
                     
         }
+
+    	xmlXPathFreeObject(result);	
     }
+
+    g_free(id_ns_prefix);
+    g_free(id_name);
+    g_free(id_xpath);
     
-     gchar* db_path = cm_get_db_path_by_name_or_default(g_db_name);
-     db_save_table(doc, schema_name, db_path);
-     g_free(db_path);
-    
-     return 0;
+    gchar* db_path = cm_get_db_path_by_name_or_default(g_db_name);
+    db_save_table(doc, schema_name, db_path);
+    g_free(db_path);
+
+    return 0;
 }
 
 
