@@ -48,8 +48,6 @@ gint create_owner_metacontact(xmlDocPtr doc) {
     
     xmlXPathObjectPtr result = db_get_nodeset(doc, BAD_CAST XPATH_NAME_SURNAME, NULL);
 
-//    gint count = 0;
-        
     xmlChar* first_name = NULL;
     xmlChar* surname = NULL;    
         
@@ -158,7 +156,6 @@ static xmlNodePtr create_link_node(const gchar* id_value)
 static gchar* build_contacts_xpath(gboolean with_owner) 
 {
     gchar* xpath_req = XPATH_OWNER_CONTACTS_IDS;
-    g_debug("AAAAAAAA %s", xpath_req);
     GSList* nodes = get_nodes_ids(METACONTACTS_SCHEMA_NAME, xpath_req);
 
     gchar* xpath_contact = NULL;
@@ -200,6 +197,9 @@ GSList* get_messages()
     gchar* xpath_req = g_strdup(DB_XPATH_MESSAGE_REQ);//build_contacts_xpath(with_owner);
 
     xmlXPathObjectPtr result = db_get_nodeset(messages_list_table, BAD_CAST xpath_req, ns);
+    
+    g_free(ns);
+    g_free(xpath_req);
 
     GSList* doc_list = NULL; 
 
@@ -214,23 +214,27 @@ GSList* get_messages()
 		    xmlBufferPtr buf = xmlBufferCreate();
 		    xmlNodeDump(buf, NULL, node, 0, 1);
 	        xmlChar* content = (xmlChar*)xmlBufferContent(buf);
-	        
-	        g_printf("\n\nNODE Content: %s", content);
+        	        
+
+	        ////g_printf("\n\nNODE Content: %s", content);
 	        
 	        xmlDocPtr elem = xmlParseDoc(content);
 	        
             xmlDocPtr external_format = db_apply_revers_stylesheet(SCHEMA_NAME_MESSAGES, elem, NULL);
 	        
-   	        g_printf("\n\nNODE Afte transform1: ");
+   	        ////g_printf("\n\nNODE Afte transform1: ");
    	        load_binary_data_to_doc(SCHEMA_NAME_MESSAGES, external_format);
 
 	        doc_list = g_slist_prepend(doc_list, xmlCopyDoc(external_format,1));
    	        xmlFreeDoc(external_format);
    	        xmlFreeDoc(elem);    
    	        xmlFreeNode(node);
-	        xmlFree(content);
+	        //xmlFree(content);
+            xmlBufferFree(buf);
                     
         }
+        
+        xmlXPathFreeObject(result);	         
     }
     return doc_list;
 }
@@ -245,6 +249,9 @@ GSList* get_owner_messages()
 
     xmlXPathObjectPtr result = db_get_nodeset(messages_list_table, BAD_CAST xpath_req, ns);
 
+    g_free(ns);
+    g_free(xpath_req);
+
     GSList* doc_list = NULL; 
 
     if (result != NULL) {
@@ -259,21 +266,24 @@ GSList* get_owner_messages()
 		    xmlNodeDump(buf, NULL, node, 0, 1);
 	        xmlChar* content = (xmlChar*)xmlBufferContent(buf);
 	        
-	        g_printf("\n\nNODE Content: %s", content);
+	        ////g_printf("\n\nNODE Content: %s", content);
 	        
 	        xmlDocPtr elem = xmlParseDoc(content);
 	        
             xmlDocPtr external_format = db_apply_revers_stylesheet(SCHEMA_NAME_OWNER_MESSAGES, elem, NULL);
 	        
-   	        g_printf("\n\nNODE Afte transform1: ");
+   	        ////g_printf("\n\nNODE Afte transform1: ");
    	        load_binary_data_to_doc(SCHEMA_NAME_OWNER_MESSAGES, external_format);
    	        doc_list = g_slist_prepend(doc_list, xmlCopyDoc(external_format,1));  
-	      xmlFreeDoc(external_format);
+            xmlFreeDoc(external_format);
    	        xmlFreeDoc(elem);    
    	        xmlFreeNode(node);
-	        xmlFree(content);
-                    
+	        //xmlFree(content);
+            xmlBufferFree(buf);        
         }
+
+        xmlXPathFreeObject(result);	         
+
     }
     return doc_list;
 }
@@ -285,50 +295,63 @@ GSList* get_contacts(gboolean with_owner) {
     xmlChar* ns = BAD_CAST cm_get_namespaces_key(SCHEMA_NAME_CONTACTS_LIST);
     xmlDocPtr contacts_list_table = get_table_from_list(SCHEMA_NAME_CONTACTS_LIST);    
     gchar* xpath_req = g_strdup(DB_XPATH_CONTACT_REQ);//build_contacts_xpath(with_owner);
-    g_debug("XPATH111 %s", xpath_req);
+
     xmlXPathObjectPtr result = db_get_nodeset(contacts_list_table, BAD_CAST xpath_req, ns);
+    
+    g_free(ns);
+    g_free(xpath_req);
 
     GSList* doc_list = NULL; 
 
     if (result != NULL) {
-	    xmlNodeSetPtr nodeset = result->nodesetval;
+        xmlNodeSetPtr nodeset = result->nodesetval;
 		
         gint size = (nodeset) ? nodeset->nodeNr - 1 : 0;
-		gint i;		
+        int i;
 
         for(i = size; i >= 0; --i) {
-		    xmlNodePtr node = xmlCopyNode(nodeset->nodeTab[i], 1);
-		    xmlBufferPtr buf = xmlBufferCreate();
-		    xmlNodeDump(buf, NULL, node, 0, 1);
+                xmlNodePtr node = xmlCopyNode(nodeset->nodeTab[i], 1);
+                xmlBufferPtr buf = xmlBufferCreate();
+                xmlNodeDump(buf, NULL, node, 0, 1);
 	        xmlChar* content = (xmlChar*)xmlBufferContent(buf);
-	        
-	        g_printf("\n\nNODE Content: %s", content);
+	    
+	        ////g_printf("\n\nNODE Content: %s", content);
 	        
 	        xmlDocPtr elem = xmlParseDoc(content);
-	        xmlDocDump(stdout, elem);
-            xmlDocPtr external_format = db_apply_revers_stylesheet(SCHEMA_NAME_CONTACTS_LIST, elem, NULL);
-	        
+
+                //xmlDocDump(stdout, elem);
+                xmlDocPtr external_format = db_apply_revers_stylesheet(SCHEMA_NAME_CONTACTS_LIST, elem, NULL);
+                xmlDocDump(stdout, external_format);
+                
    	       
    	        load_binary_data_to_doc(SCHEMA_NAME_CONTACTS_LIST, external_format);
    	        doc_list = g_slist_prepend(doc_list, xmlCopyDoc(external_format,1));
    	        xmlFreeDoc(external_format);
-   	        xmlFreeDoc(elem);    
-   	        xmlFreeNode(node);
-	        xmlFree(content);
-                    
+   	        xmlFreeDoc(elem); 
+   	        xmlFreeNode(node); 
+	        //xmlFree(content);
+                xmlBufferFree(buf); 
         }
+        
+        xmlXPathFreeObject(result);	      
     }
+
     return doc_list;
 }
 
 GSList* get_profiles(gboolean with_owner) {
 
+    g_debug("\n get_profiles start! \n");
+
     xmlChar* ns = BAD_CAST cm_get_namespaces_key(SCHEMA_NAME_CONTACTS);
     xmlDocPtr contacts_list_table = get_table_from_list(SCHEMA_NAME_CONTACTS);    
     gchar* xpath_req = g_strdup(DB_XPATH_PERSON_REQ);//build_contacts_xpath(with_owner);
-    g_debug("XPATH1111 %s", xpath_req);
+
     xmlXPathObjectPtr result = db_get_nodeset(contacts_list_table, BAD_CAST xpath_req, ns);
 
+    g_free(ns);
+    g_free(xpath_req);
+
     GSList* doc_list = NULL; 
 
     if (result != NULL) {
@@ -343,22 +366,25 @@ GSList* get_profiles(gboolean with_owner) {
 		    xmlNodeDump(buf, NULL, node, 0, 1);
 	        xmlChar* content = (xmlChar*)xmlBufferContent(buf);
 	        
-	        g_printf("\n\nNODE Content: %s", content);
+	        ////g_printf("\n\nNODE Content: %s", content);
 	        
 	        xmlDocPtr elem = xmlParseDoc(content);
 
             xmlDocPtr external_format = db_apply_revers_stylesheet(SCHEMA_NAME_CONTACTS, elem, NULL);
 	        
-   	        g_printf("\n\nNODE Afte transform1: ");
+   	        ////g_printf("\n\nNODE Afte transform1: ");
    	        load_binary_data_to_doc(SCHEMA_NAME_CONTACTS, external_format);
    	        doc_list = g_slist_prepend(doc_list, xmlCopyDoc(external_format,1));
    	        xmlFreeDoc(external_format);
    	        xmlFreeDoc(elem);    
    	        xmlFreeNode(node);
-	        xmlFree(content);
-                    
+	        //xmlFree(content);
+            xmlBufferFree(buf);        
         }
+        xmlXPathFreeObject(result);	      
+
     }
+    g_debug("\n get_profiles END! \n");
     return doc_list;
 }
 
@@ -425,7 +451,6 @@ gint create_or_update_owner_message(xmlDocPtr message, gchar* outer_id)
 gint create_or_update_contact1(xmlDocPtr contact, gchar* outer_id)
 {
 
-g_debug("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ");
 
     if (contact == NULL || outer_id == NULL) {
         return FAILURE;
@@ -434,7 +459,7 @@ g_debug("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ");
     gchar* xpath_req = g_strconcat(DB_XPATH_KNOWNAS_ID_REQ, "='", outer_id, "']", NULL );
     xmlDocPtr metacontacts_table = get_table_from_list(METACONTACTS_SCHEMA_NAME);
     xmlChar* ns = BAD_CAST cm_get_namespaces_key(METACONTACTS_SCHEMA_NAME);
-    
+
     g_debug("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! %s", xpath_req);
 
     if (db_get_nodes_count(metacontacts_table, BAD_CAST xpath_req, ns) == 0) {
