@@ -31,6 +31,7 @@ CTF_TEST_DATA_FILE_NAME_DECL;
 
 int counter = 0;
 static int global_temp = 0;
+int attempts = 0;
 
 int init_event_manager(int time)
 {
@@ -73,7 +74,6 @@ char* event_message = "\
     free(action);
     free(str_time);
     GList* list;
-    msa_driver_info* info;
 
     xmlNodePtr node;
     xmlNodePtr node_root;
@@ -86,7 +86,9 @@ char* event_message = "\
 
     doc_root = xmlParseDoc(event_struct);
     node = xmlDocGetRootElement(doc);
-
+    xmlUnlinkNode(node);
+    xmlDocSetRootElement(doc, NULL);
+    
     xmlXPathObject* Obj = xpath("//TransitData/Content/Signal/Content", doc_root);
     node_root = Obj->nodesetval->nodeTab[0];
 
@@ -99,6 +101,10 @@ char* event_message = "\
 
     set_events(doc_char);
 
+    xmlXPathFreeObject(Obj);
+    xmlFreeDoc(doc);
+    xmlFreeDoc(doc_root);
+    g_free(event_struct);
     return 0;
 }
 
@@ -172,28 +178,28 @@ static char* get_captcha(guint32 captcha_sid)
  * @param doc - response
  * @return 0 on success or 1 otherwise.
  */
-int vk_req(xmlDocPtr reqXml, xmlDocPtr doc, msa_driver_info* info)
+int vk_req(xmlDocPtr reqXml, xmlDocPtr doc, msa_module* info)
 {
     int i, len;
     int captch = 0;
     int init_status = 0;
-    char* url;
-    char* remixmid;
-    char* remixsid;
-    char* class;
-    char* function;
-    char* tmp;
-    xmlXPathObject *Obj;
+    char* url = NULL;
+    char* remixmid = NULL;
+    char* remixsid = NULL;
+    char* class = NULL;
+    char* function = NULL;
+    char* tmp = NULL;
+    xmlXPathObject *Obj = NULL;
 
     global_temp++;
     
-    g_print("IN VK_REQ!!! %d",global_temp);
+    g_print("IN VK_REQ!!! %d\n", global_temp);
     counter = 0;
     xmlDocDump(stdout, reqXml);
 
 //Prepare response
-    xmlNodePtr rootNode, node, childNode;
-    xmlDocPtr reqXml2;
+    xmlNodePtr rootNode = NULL, node = NULL, childNode = NULL;
+    xmlDocPtr reqXml2 = NULL;
     rootNode = xmlNewDocNode(doc, NULL,  "Response", NULL);
     xmlDocSetRootElement(doc, rootNode);
 
@@ -205,13 +211,14 @@ int vk_req(xmlDocPtr reqXml, xmlDocPtr doc, msa_driver_info* info)
     node = xmlNewDocNode(doc, NULL,   PARAMS,  NULL);
     childNode = xmlAddChild(rootNode, node);
  
-//Convert message text to url encode
-    xmlNodePtr node2;
-    if (strcmp(function, GET_SETTINGS) == 0) {
+    xmlNodePtr node2 = NULL;
+    g_debug("function = %s", function);
+    if (g_strcmp0(function, GET_SETTINGS) == 0) {
         get_settings(doc);
        return 0;
     }
-    if(strcmp(function, SET_SETTINGS) == 0) {
+    
+    if(g_strcmp0(function, SET_SETTINGS) == 0) {
         if (set_settings(reqXml, doc, info)) {
             info_message("404", doc, DRV_SETT_ERROR, 1);
         } else {
@@ -219,21 +226,23 @@ int vk_req(xmlDocPtr reqXml, xmlDocPtr doc, msa_driver_info* info)
         }
        return 0;
     }
-    if (strcmp(function, CAPTCHA_MESSAGE) == 0) {
+    if (g_strcmp0(function, CAPTCHA_MESSAGE) == 0) {
         captch = 1;
 
-        char* captcha_code;
+        char* captcha_code = NULL;
         Obj = xpath("//Request/Params/string[@name='text']", reqXml);
         node = Obj->nodesetval->nodeTab[0];
         captcha_code = xmlNodeGetContent(node);
         g_debug("captcha code %s", captcha_code);
+        xmlXPathFreeObject(Obj);
 
         Obj = xpath("//Request/Params/string[@name='oldRequest']/Request/Params/string[@name='fccode']", reqXml);
         node = Obj->nodesetval->nodeTab[0];
         xmlNodeSetContent(node, captcha_code);
+        xmlXPathFreeObject(Obj);
 
         Obj = xpath("//Request/Params/string[@name='oldRequest']/Request", reqXml);
-g_debug("GET OBJ");
+	
 	if(Obj != NULL) {
 		g_debug("OBG != NULL");
             node = Obj->nodesetval->nodeTab[0];
@@ -243,9 +252,10 @@ g_debug("GET OBJ");
             reqXml2 = xmlNewDoc("1.0");
             xmlDocSetRootElement(reqXml2, childNode);
 	    g_debug("SET");
+            xmlXPathFreeObject(Obj);
         } else {
             return 1;
-        }
+       }
     }
 
     if(captch) {
@@ -257,7 +267,7 @@ g_debug("GET OBJ");
     xmlSetProp(rootNode, FUNCTION, function);
 
     init_status = initialization(&remixmid, &remixsid);
-
+    attempts = 0;
     if (init_status != 0) {
         if(init_status == -2) {
             //info_message("402", doc, DRV_AUTH_ERROR, 1);
@@ -266,14 +276,27 @@ g_debug("GET OBJ");
                 else
                     captcha_message(doc, reqXml);
                 return 0;
-        } else
+        }
+        if (init_status == 2){
             info_message("403", doc, DRV_NETW_ERROR, 1);
+            return 0;
+        }
+        if(init_status == 1) {
+            info_message("402", doc, DRV_AUTH_ERROR, 1);
+            return 0;
+        }
+                 
     }
 
     if(captch)
         make_request( reqXml2, doc, remixmid, remixsid);
     else
         make_request( reqXml, doc, remixmid, remixsid);
+
+    if(remixmid)
+        g_free(remixmid);
+    if(remixsid)
+        g_free(remixsid);
     return 0;
 }
 
@@ -288,18 +311,20 @@ g_debug("GET OBJ");
  */
 int make_request(xmlDocPtr reqXml, xmlDocPtr doc, char* remixmid, char* remixsid)
 {
+    gchar* converted_friends = NULL;
     char* tmp;
     char* url;
     char* class = get_req_class(reqXml);
     char* function = get_req_function(reqXml);
     int num = 0;
+    int init_status = 0;
 
     url = make_url(reqXml, remixmid, remixsid);
 
     xmlNodePtr rootNode;
 
     if (url == NULL || strlen(url)  < 1 ) {
-        if (strcmp(function, GET_BINARY_DATA) == 0 ) {
+        if (g_strcmp0(function, GET_BINARY_DATA) == 0 ) {
             counter = -1;
             return 0;
         } else {
@@ -308,19 +333,21 @@ int make_request(xmlDocPtr reqXml, xmlDocPtr doc, char* remixmid, char* remixsid
         }
     }
     if (http_get(url, info_proxy, info_port, NULL, &tmp) == 200) {
-        if (strcmp(function, GET_BINARY_DATA) == 0 ) {
+        if (g_strcmp0(function, GET_BINARY_DATA) == 0 ) {
             if (counter == -1) {
                 return 0;
             }
             parser_image(doc, tmp, url);
+            g_free(url);
+            g_free(tmp);
             counter++;
             make_request( reqXml, doc, remixmid, remixsid);
             return 0;
         }
-         
+        g_free(url);
         switch (check(tmp)) {
             case 0:
-                if (strcmp(function, SEND_MESSAGE) == 0) {
+                if (g_strcmp0(function, SEND_MESSAGE) == 0) {
                     info_message("405", doc, DRV_MESS_ERROR, 1);
 		    g_free(tmp);
                     return 0;
@@ -328,21 +355,22 @@ int make_request(xmlDocPtr reqXml, xmlDocPtr doc, char* remixmid, char* remixsid
                 g_debug("check OK");
             case 1:
 
-                if (strcmp(function, GET_MY_PROFILE) == 0 || strcmp(function, UPDATE_PROFILE) == 0) {
+                if (g_strcmp0(function, GET_MY_PROFILE) == 0 || g_strcmp0(function, UPDATE_PROFILE) == 0) {
                     if(parser_profile(doc, tmp, remixmid) == 1){
                         info_message("403", doc, DRV_RESP_ERROR, 1);
                     }
                     g_free(tmp);      	    
                 }
-                if (strcmp(function, SEND_MY_PROFILE) == 0) {
+                if (g_strcmp0(function, SEND_MY_PROFILE) == 0) {
                     info_message("400", doc, DRV_PROF_SAVED, 0);
                     g_free(tmp);
                     return 0;
                 }
-                if (strcmp(function, GET_LIST_FRIENDS) == 0) {
-                    tmp = g_convert(tmp, -1, UTF8, CP1251, NULL, NULL, NULL);
-                    num = parser_friends(tmp, doc);
+                if (g_strcmp0(function, GET_LIST_FRIENDS) == 0) {
+                    converted_friends = g_convert(tmp, -1, UTF8, CP1251, NULL, NULL, NULL);
                     g_free(tmp);
+                    num = parser_friends(converted_friends, doc);
+                    g_free(converted_friends);
                     if (num == PAGE_SIZE) {
                         counter++;
                         make_request( reqXml, doc, remixmid, remixsid);
@@ -350,7 +378,7 @@ int make_request(xmlDocPtr reqXml, xmlDocPtr doc, char* remixmid, char* remixsid
                         return 0;
                     }
                 }
-                if (strcmp(function, UPDATE_INBOX_MESSAGES) == 0 || strcmp(function, UPDATE_OUTBOX_MESSAGES) == 0) {
+                if (g_strcmp0(function, UPDATE_INBOX_MESSAGES) == 0 || g_strcmp0(function, UPDATE_OUTBOX_MESSAGES) == 0) {
                     num = parser_messages(tmp, doc);
                     g_free(tmp);
                     if (num == PAGE_SIZE && counter < MAX_COUNTER) {
@@ -360,7 +388,7 @@ int make_request(xmlDocPtr reqXml, xmlDocPtr doc, char* remixmid, char* remixsid
                         return 0;
                     }
                 }
-                if (strcmp(function, GET_NEW_MESSAGES) == 0) {
+                if (g_strcmp0(function, GET_NEW_MESSAGES) == 0) {
                     g_debug("GET_NEW_MESSAGES");
                     num = parser_new_messages(tmp);
                     g_free(tmp);
@@ -368,6 +396,7 @@ int make_request(xmlDocPtr reqXml, xmlDocPtr doc, char* remixmid, char* remixsid
                     if (num > 0) {
                         url = g_strdup_printf("http://userapi.com/data?act=inbox&from=0&to=%d&id=%s&sid=%s",num,remixmid,remixsid);
                         if(http_get(url, info_proxy, info_port, NULL, &tmp) == 200){
+                            g_free(url);
                             num = parser_messages(tmp, doc);
                             g_free(tmp);
 			    read_message(doc, remixmid, remixsid);
@@ -378,14 +407,22 @@ int make_request(xmlDocPtr reqXml, xmlDocPtr doc, char* remixmid, char* remixsid
                     }
                 }
 
-                if (strcmp(function, SEND_MESSAGE) == 0) {
+                if (g_strcmp0(function, SEND_MESSAGE) == 0) {
                     info_message("400", doc, DRV_MESS_SEND, 0);
                     g_free(tmp);
                     return 0;
                 }
                 break;
             case -1:
-                info_message("401", doc, DRV_AUTH_ERROR, 1);
+                unset_settings(REMIXSID);
+                if (attempts == 0) {
+                    attempts = 1;
+                    init_status = initialization(&remixmid, &remixsid);
+                    if (init_status == 0)
+                        make_request(reqXml, doc, remixmid, remixsid);
+                }
+                else 		
+                    info_message("401", doc, DRV_AUTH_ERROR, 1);
                 g_free(tmp);
 		break;
             case -2:
@@ -424,14 +461,6 @@ int initialization(char** remixmid, char** remixsid)
     GConfClient* client;
     client = gconf_client_get_default ();
 #ifndef TEST
-    path = g_strconcat(PATH, LOGIN, NULL);
-    email = gconf_client_get_string (client, path, NULL);
-    g_free(path);
-
-    path = g_strconcat(PATH, PASSWORD, NULL);
-    pass = gconf_client_get_string (client, path, NULL);
-    g_free(path);
-    
     path = g_strconcat(PATH, REMIXMID, NULL);
     *remixmid = gconf_client_get_string (client, path, NULL);
     g_free(path);
@@ -445,17 +474,31 @@ int initialization(char** remixmid, char** remixsid)
 #endif
 
     if(*remixmid == NULL || *remixsid == NULL ) {
+        path = g_strconcat(PATH, LOGIN, NULL);
+        email = gconf_client_get_string (client, path, NULL);
+        g_free(path);
+
+        path = g_strconcat(PATH, PASSWORD, NULL);
+        pass = gconf_client_get_string (client, path, NULL);
+        g_free(path);
+
         g_print("dr_vk: authorization\n");
         auth_status = authorize(email, pass);
+        g_free(email);
+        g_free(pass);
         if (auth_status != 0 ) {
             g_debug("dr_vk: Could not get remixmid, remixsid\n"); 
-            if (auth_status == -2 ) {
-                return -2;
-            }
-            return 1;
+            //if (auth_status == -2 ) {
+            //    return -2;
+            //}
+            return auth_status;
         } else {
-            *remixmid = gconf_client_get_string (client, g_strconcat(PATH, REMIXMID, NULL), NULL);
-            *remixsid = gconf_client_get_string (client, g_strconcat(PATH, REMIXSID, NULL), NULL);
+            path = g_strconcat(PATH, REMIXMID, NULL); 
+            *remixmid = gconf_client_get_string (client, path, NULL);
+            g_free(path);
+            path = g_strconcat(PATH, REMIXSID, NULL);
+            *remixsid = gconf_client_get_string (client, path, NULL);
+            g_free(path);
         }
     }
     g_object_unref((gpointer)client);
@@ -476,6 +519,8 @@ int get_settings(xmlDocPtr doc)
     GConfClient* client;
     gchar* login;
     gchar* password;
+    gchar* path;
+    gchar* tmp;
     gint status = 0, autoupdate = 0;
     xmlNodePtr rootNode, childNode, node;
     
@@ -483,27 +528,46 @@ int get_settings(xmlDocPtr doc)
     rootNode = rootNode->children;
     
     client = gconf_client_get_default ();
-    status = gconf_client_get_int (client, g_strconcat(PATH, STATUS, NULL), NULL);
-    login = gconf_client_get_string (client, g_strconcat(PATH, LOGIN, NULL), NULL);
-    password = gconf_client_get_string (client, g_strconcat(PATH, PASSWORD, NULL), NULL);
-    autoupdate = gconf_client_get_int (client, g_strconcat(PATH, AUTOUPDATE, NULL) , NULL);
+
+    path = g_strconcat(PATH, STATUS, NULL);
+    status = gconf_client_get_int (client, path, NULL);
+    g_free(path);
+
+    path = g_strconcat(PATH, LOGIN, NULL);
+    login = gconf_client_get_string (client, path, NULL);
+    g_free(path);
+
+    path = g_strconcat(PATH, PASSWORD, NULL);
+    password = gconf_client_get_string (client, path, NULL);
+    g_free(path);
+
+    path = g_strconcat(PATH, AUTOUPDATE, NULL);
+    autoupdate = gconf_client_get_int (client, path , NULL);
+    g_free(path);
     
     childNode = xmlNewDocNode(doc, NULL, BAD_CAST STRING, login);
     xmlSetProp(childNode, NAME, LOGIN);
     childNode = xmlAddChild(rootNode, childNode);
-    
+    g_free(login);
+
     childNode = xmlNewDocNode(doc, NULL, BAD_CAST STRING, password);
     xmlSetProp(childNode, NAME, PASSWORD);
     childNode = xmlAddChild(rootNode, childNode);
-    
-    childNode = xmlNewDocNode(doc, NULL, BAD_CAST NUMBER, g_strdup_printf("%d",autoupdate));
+    g_free(password);
+
+    tmp = g_strdup_printf("%d",autoupdate);
+    childNode = xmlNewDocNode(doc, NULL, BAD_CAST NUMBER, tmp);
     xmlSetProp(childNode, NAME, AUTOUPDATE);
     childNode = xmlAddChild(rootNode, childNode);
+    g_free(tmp);
     
-    childNode = xmlNewDocNode(doc, NULL, BAD_CAST BOOLEAN, g_strdup_printf("%d",status));
+    tmp = g_strdup_printf("%d",status);
+    childNode = xmlNewDocNode(doc, NULL, BAD_CAST BOOLEAN, tmp);
     xmlSetProp(childNode, NAME, STATUS);
     childNode = xmlAddChild(rootNode, childNode);
+    g_free(tmp);
 
+    g_object_unref((gpointer)client);
     g_debug("get_settings END");
    return 0;
 }
@@ -515,7 +579,7 @@ int get_settings(xmlDocPtr doc)
  * @param doc - response
 * @return 0 on success or 1 otherwise.
  */
-int set_settings (xmlDocPtr reqXml, xmlDocPtr doc, msa_driver_info* info)
+int set_settings (xmlDocPtr reqXml, xmlDocPtr doc, msa_module* info)
 {
     g_debug("set_settings START");
 
@@ -533,21 +597,21 @@ int set_settings (xmlDocPtr reqXml, xmlDocPtr doc, msa_driver_info* info)
 
     while(rootNode != NULL) {
         g_debug("%s", rootNode->name);
-        if (strcmp(xmlGetProp(rootNode, NAME),LOGIN) == 0) {
+        if (g_strcmp0(xmlGetProp(rootNode, NAME),LOGIN) == 0) {
             path = g_strconcat(PATH, LOGIN, NULL);
             temp = xmlNodeGetContent(rootNode);	    
             checked = gconf_client_set_string (client, path, temp, NULL);
             g_free(path);    
 	    g_free(temp);
         }
-        if (strcmp(xmlGetProp(rootNode, NAME),PASSWORD) == 0) {
+        if (g_strcmp0(xmlGetProp(rootNode, NAME),PASSWORD) == 0) {
             path = g_strconcat(PATH, PASSWORD, NULL);
 	    temp = xmlNodeGetContent(rootNode);
             checked = gconf_client_set_string (client, path, temp, NULL);
             g_free(path);
 	    g_free(temp);
         }
-        if (strcmp(xmlGetProp(rootNode, NAME),AUTOUPDATE) == 0) {
+        if (g_strcmp0(xmlGetProp(rootNode, NAME),AUTOUPDATE) == 0) {
             int time = 0;
 	    temp = (char*)xmlNodeGetContent(rootNode);
             time = atoi(temp);
@@ -559,7 +623,7 @@ int set_settings (xmlDocPtr reqXml, xmlDocPtr doc, msa_driver_info* info)
             g_free(path);
 	    g_free(temp);
         }
-        if (strcmp(xmlGetProp(rootNode, NAME),STATUS) == 0) {
+        if (g_strcmp0(xmlGetProp(rootNode, NAME),STATUS) == 0) {
             path = g_strconcat(PATH, STATUS, NULL);
 	    temp = xmlNodeGetContent(rootNode);
 #ifndef TEST
@@ -574,16 +638,28 @@ int set_settings (xmlDocPtr reqXml, xmlDocPtr doc, msa_driver_info* info)
         if(!checked)
             status = 1;
     }
-    path = g_strconcat(PATH, REMIXMID, NULL);
-    gconf_client_unset(client, path, NULL);
-    g_free(path);
-    path = g_strconcat(PATH, REMIXSID, NULL);
-    gconf_client_unset(client, path, NULL);
-    g_free(path);
-    g_object_unref((gpointer)client);
-    g_debug("set_settings END");
 
-        return status;
+    unset_settings(REMIXMID);
+    unset_settings(REMIXSID);
+    
+    return status;
+}
+
+/**
+ * Unset value in gconf
+ * @param name - name of setting for unset
+*/
+void unset_settings(char* name){
+    GConfClient* client;
+    gchar* path;
+
+    client = gconf_client_get_default ();
+
+    path = g_strconcat(PATH, name, NULL);
+    gconf_client_unset(client, path, NULL);
+    g_free(path);
+
+    g_object_unref((gpointer)client);
 }
 
 /**
@@ -597,6 +673,102 @@ int set_settings (xmlDocPtr reqXml, xmlDocPtr doc, msa_driver_info* info)
  * @return 0 on success or 1 otherwise.
  */
 int authorize(char *email, char *pass)
+{
+    FILE* fpin;
+    int i;
+    char *head, *body;
+    char url[URL_SIZE];
+    char* mid = NULL, sid[MID_SIZE];
+    char *tmp;
+    char *resp;
+    char* post_data;
+    int code = 0;
+    struct curl_slist *cookies;
+    gchar* path;
+
+    GConfClient* client;
+    client = gconf_client_get_default ();
+
+    g_print("authorize START");
+    if ( email == NULL || pass == NULL) {
+        g_debug("email = NULL");
+        return 1;
+    }
+    post_data = g_strdup_printf("email=%s&pass=%s&expire=0&vk=", email, pass);
+
+#ifdef TEST
+    info_proxy = g_strdup("proxy.karelia.ru");
+    info_port = 81;
+#endif
+
+    code = http_post("http://login.vk.com/?act=login", info_proxy, info_port, post_data, NULL, &body, &cookies);
+
+    if (code == 200) {
+
+        int i = 0;
+	gchar** cookie;
+	while (cookies) {
+	    cookie = g_strsplit(cookies->data,"\t", 20);
+	    i = 0;
+	    while(cookie[i] != NULL){
+	        if(strcmp(cookie[i], "l") == 0) {
+		    mid = g_strdup(cookie[i+1]);
+                    g_debug("mid = %s", mid);
+                }
+	        i++;
+            }
+            g_strfreev(cookie);
+            cookies = cookies->next;
+        }
+        curl_slist_free_all(cookies);
+	if ( mid != NULL ) {
+	    path = g_strconcat(PATH, REMIXMID, NULL);
+	    gconf_client_set_string (client, path, mid, NULL);
+	    g_free(path);
+            g_free(mid);
+	} else {
+            g_debug("mid not found");
+	    //g_free(mid);
+	    return 1;
+	}
+
+
+    //Get remixsid
+        g_debug("BODY %s", body);
+        if(body != NULL){
+            tmp = g_strrstr(body, "id='s' value='") + 14;
+            if(tmp == NULL){
+                path = g_strconcat(PATH, REMIXMID, NULL);
+                gconf_client_unset(client, path, NULL);
+                g_free(body);
+                g_free(path);
+	        g_debug("no sid");
+	        return 1;
+            } else {
+	        g_debug("sid found");
+	        sscanf(tmp, "%s", sid);
+	        sid[strlen(sid)-1]='\0';
+                path = g_strconcat(PATH, REMIXSID, NULL);
+                gconf_client_set_string (client, path, sid, NULL);
+                g_free(path);
+                g_free(body);
+                return 0;
+            }
+        }
+	path = g_strconcat(PATH, REMIXMID, NULL);
+	gconf_client_unset(client, path, NULL);
+	g_free(path);
+        return 1;
+    } else 
+          if (code == 400)
+              return 2;
+          else    
+              return 1;
+}
+
+
+/*
+int authorize(char *email, char *pass)
 {
     g_type_init();
     FILE* fpin;
@@ -632,6 +804,7 @@ int authorize(char *email, char *pass)
             tmp = g_strrstr(buf, "sid=") + 4;
             if(tmp == NULL) {
                 g_debug("no sid");
+                g_free(buf);
                 return 1;
             } else
                 g_debug("sid found");
@@ -641,8 +814,10 @@ int authorize(char *email, char *pass)
                 path = g_strconcat(PATH, REMIXSID, NULL);    
                 gconf_client_set_string (client, path, sid, NULL);
 		g_free(path);
-            } else 
+            } else {
+                g_free(buf);
                 return 1;
+            }
             tmp = NULL;
             tmp = g_strrstr(buf, "remixmid=");
             if(tmp == NULL) {
@@ -650,6 +825,7 @@ int authorize(char *email, char *pass)
                 path = g_strconcat(PATH, REMIXSID, NULL);
                 gconf_client_unset(client, path, NULL);
                 g_free(path);
+                g_free(buf);
                 return 1;
             } else 
                 tmp = tmp + 9;
@@ -659,8 +835,11 @@ int authorize(char *email, char *pass)
 		path = g_strconcat(PATH, REMIXMID, NULL);
                 gconf_client_set_string (client, path, mid, NULL);
 		g_free(path);
-            } else 
+                g_free(buf);
+            } else {
+                g_free(buf);
                 return 1;
+            }
         } else 
             return 1;
     }
@@ -670,6 +849,7 @@ int authorize(char *email, char *pass)
         return 1;
    return 0;
 }
+*/
 
 /**
  * Get class of request
@@ -692,9 +872,12 @@ char* get_req_class(xmlDocPtr reqXml)
  */
 char* get_req_function(xmlDocPtr reqXml)
 {
-    xmlNodePtr rootNode;
-    rootNode = xmlDocGetRootElement(reqXml);
-    return xmlGetProp(rootNode, FUNCTION);
+    xmlNodePtr rootNode = NULL;
+    if (reqXml != NULL)
+	rootNode = xmlDocGetRootElement(reqXml);
+    if (rootNode != NULL)
+	return xmlGetProp(rootNode, FUNCTION);
+    return NULL;
 }
 
 int read_message(xmlDocPtr reqXml, char* remixmid, char* remixsid)
@@ -759,6 +942,7 @@ char* make_url(xmlDocPtr reqXml, char* remixmid, char* remixsid)
     if (root == NULL)
         return NULL;
     url = xmlNodeGetContent(root);
+    
     xsltFreeStylesheet(cur);    
     xmlFreeDoc(urlXml);
     g_free((gpointer*)params[0]);
@@ -867,12 +1051,11 @@ int captcha_message(xmlDocPtr doc, xmlDocPtr reqXml)
 /**
  * Perform HTTP GET request
  *
- * @param reqXml - request
+ * @param url - request
  * @param proxy - proxy address 
  * @param port - proxy port
  * @param header - buffer for header of response
  * @param body - buffer for body of response
- * @param type - type of request data (image, text)
  * @return http server response code 
  */
 int http_get(const char* url, const char* proxy, long port, char** header, char** body)
@@ -918,25 +1101,112 @@ int http_get(const char* url, const char* proxy, long port, char** header, char*
     g_debug("TYPE %s", type2);
 
     if (header != NULL) {
-        *header = chunk2.memory;
+        *header = g_strdup(chunk2.memory);
     }
 
     g_print("HEADER  %s\n", chunk2.memory);
+    if(chunk2.memory)
+        free(chunk2.memory);
 
     if (body != NULL) {
-        if (strcmp(type2, "image/jpeg") == 0) {
+        if (g_strcmp0(type2, "image/jpeg") == 0) {
             *body = g_base64_encode (chunk.memory, chunk.size);
-            g_free(chunk.memory);
         } else {
-        *body = chunk.memory;
+        *body = g_strdup(chunk.memory);
         }
     }
-    //g_print("CONTENT  %s\n", chunk.memory);
+    if(chunk.memory)
+        free(chunk.memory);
+    //free(type2);
+    //g_print("CONTENT  %s\n", *body);
 
     curl_easy_cleanup(c);
     return code;
 }
 
+/**
+ * Perform HTTP POST request
+ *
+ * @param url - request
+ * @param proxy - proxy address
+ * @param port - proxy port
+ * @param post_data - data to send
+ * @param header - buffer for header of response
+ * @param body - buffer for body of response
+ * @param cookies - list of cookies from server
+ * @return http server response code
+ */
+
+int http_post(const char* url, const char* proxy, long port, char* post_data, char** header, char** body, struct curl_slist** cookies)
+{
+    CURL* c;
+    CURLcode code;
+    CURLcode res;
+    char* type2;
+    struct MemoryStruct chunk,chunk2;
+
+    chunk.memory = NULL;
+    chunk.size = 0;
+
+    chunk2.memory = NULL;
+    chunk2.size = 0;
+
+
+    c = curl_easy_init();
+    g_print("url in http_post %s", url);
+
+    curl_easy_setopt(c, CURLOPT_URL, url);
+
+    curl_easy_setopt(c, CURLOPT_PROXY, proxy);
+    curl_easy_setopt(c, CURLOPT_PROXYPORT, port);
+    curl_easy_setopt(c, CURLOPT_TIMEOUT, 120);
+
+
+    curl_easy_setopt(c, CURLOPT_POST, 1);
+    curl_easy_setopt(c, CURLOPT_POSTFIELDS, post_data);
+    curl_easy_setopt(c, CURLOPT_POSTFIELDSIZE, -1);
+
+    curl_easy_setopt(c, CURLOPT_COOKIEFILE, "");
+
+    curl_easy_setopt(c, CURLOPT_WRITEFUNCTION, WriteMemoryCallback);
+    curl_easy_setopt(c, CURLOPT_HEADERFUNCTION, WriteMemoryCallback);
+
+    curl_easy_setopt(c, CURLOPT_WRITEDATA, (void *)&chunk);
+    curl_easy_setopt(c, CURLOPT_WRITEHEADER, (void *)&chunk2);
+    g_debug("send request");
+    
+    if (curl_easy_perform(c) != 0) {
+        fprintf(stderr, "Can't perform the request\n");
+        return 400;
+    }
+    
+    res = curl_easy_getinfo(c, CURLINFO_COOKIELIST, &*cookies);
+    if (res != CURLE_OK) {
+        return 400;
+    }
+    
+    curl_easy_getinfo(c, CURLINFO_RESPONSE_CODE, &code );
+    g_debug("CODE %d", code);
+    
+    
+    if (header != NULL) {
+        *header = g_strdup(chunk2.memory);
+    }
+    g_print("HEADER  %s\n", chunk2.memory);
+    if(chunk2.memory)
+        free(chunk2.memory);
+    
+    if (body != NULL) {
+        *body = g_strdup(chunk.memory);
+        if(chunk.memory) 
+	    g_free(chunk.memory);
+    }
+    curl_easy_cleanup(c);
+    return code;
+}
+
+
+
 /**
  * @param req - xpath req
  * @param doc - xmlDocPtr  
@@ -960,7 +1230,8 @@ xmlXPathObject* xpath(char* req, xmlDocPtr doc)
 
 	g_debug("vk_xpath: end");
 
-	xmlFree(Ctx);
+        xmlXPathFreeContext(Ctx);
+	//xmlFree(Ctx);
 
 	return Obj;
 
