@@ -105,9 +105,9 @@ static void shutdown_drivers();
 
 
 
-#ifdef INCLUDE_TEST_FUNC
-#include "../../test/kernel_test/kernel_test_func.c"
-#endif
+//#ifdef INCLUDE_TEST_FUNC
+//#include "../../test/kernel_test/kernel_test_func.c"
+//#endif
 
 
 /**************************************************/
