@@ -6,12 +6,11 @@
 #include <glib.h>
 #include "kernel/kernel.h"
 #include "msa.h"
-#include <gettext.h>
+/* #include <gettext.h> */
 
 
 #define CONST_PROXY "proxy.karelia.ru"
 #define CONST_PORT 81
-#define _(String) gettext (String)
 
 #define OSSO_SERVICE "ru.karelia.cs.mysocials"
 #ifdef __ARMEL__
@@ -127,7 +126,6 @@ static int start_module(const char* id, int argc, char *argv[])
     gpointer value;
     msa_module_disp* target_module;
     msa_module_disp* target_kernel;
-    msa_driver_info* drv;
 
     value = g_hash_table_lookup(table_mod, (gpointer)id);
       
@@ -136,7 +134,6 @@ static int start_module(const char* id, int argc, char *argv[])
       
     target_kernel = (msa_module_disp*)value;
     value = (gpointer)target_kernel->msa_mod; 
-    drv = (msa_driver_info*)list_drivers->data;
     
     if(target_module->msa_mod->module_start != NULL) {
         target_module->msa_mod->module_start(value, (gpointer)list_drivers, argc, argv);
@@ -236,14 +233,14 @@ static void msa_get_conic_settings(ConIcConnection* connection, gchar** proxy, g
 static void msa_set_driver_status(msa_module_status _status, gchar* proxy, gint port)
 {
     GList* node;
-    msa_driver_info* info;
+    msa_module* info;
     msa_module_disp* target_module;
     gpointer value;
 
 	
     for (node = list_drivers; node != NULL; node = node->next) {
 	
-        info = (msa_driver_info*)node->data;
+        info = (msa_module*)node->data;
         info->proxy = proxy;
         info->port = port;
         info->status = _status;
@@ -278,7 +275,7 @@ static int init_event_manager()
 </TransitData>", NULL);
 
     GList* list;
-    msa_driver_info* info;
+    msa_module* info;
 
     xmlNodePtr node;
     xmlNodePtr node_root;
@@ -291,7 +288,7 @@ static int init_event_manager()
         
     for (list = list_drivers; list != NULL; list = list->next) {
 
-        info = (msa_driver_info*)list->data;       
+        info = (msa_module*)list->data;       
         add_target(doc, info->id, 0);
 
     }  
