@@ -64,7 +64,6 @@ static void ui_start(gpointer _data, gpointer list_drv, int argc, char* argv[])
     kernel = (msa_module*)_data;
     GList* list = (GList*)list_drv;
     GList* node;
-    msa_driver_info* info;
  
     /* GTK INIT */
     gtk_init(NULL, NULL);
@@ -85,7 +84,7 @@ static void ui_start(gpointer _data, gpointer list_drv, int argc, char* argv[])
  * @param
  * @return
 **/
-int ui_got_response(xmlDocPtr _response, xmlDocPtr* doc, msa_driver_info* ui_info_not_use)
+int ui_got_response(xmlDocPtr _response, xmlDocPtr* doc, msa_module* ui_info_not_use)
 {
         gchar* class_name;
         gchar* func;
@@ -1145,7 +1144,7 @@ int ui_show_info(gpointer ptr_request)
         callback_button_friends_get(NULL, NULL);   
     }
 
-    if (strcmp(code, DB_UPDATE_MESSAGE_INBOX_MESSAGES_CODE) == 0) {
+    if (strcmp(code, DB_UPDATE_MESSAGE_INBOX_MESSAGES_CODE) == 0 || strcmp(code, DB_NEW_INBOX_MESSAGES_CODE) == 0) {
         callback_button_messages_get(NULL, NULL);   
     }
     
