@@ -40,7 +40,7 @@ void callback_full(GtkAction* action, gpointer data)
             g_print("fullscreen\n");
             /* activate toolbar in fullscreen mode */
             if (!ui_data->tool)
-                gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(ui_data->menu_tool), !ui_data->tool);
+                gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ui_data->menu_tool), !ui_data->tool);
         } else {
             gtk_window_unfullscreen(GTK_WINDOW(ui_data->window));
             g_print("unfullscreen\n");
@@ -48,7 +48,7 @@ void callback_full(GtkAction* action, gpointer data)
     } else {
         /* if is called from toolbar */
         /* set "Fullscreen" item in menu active or not */       
-        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(ui_data->menu_full), !ui_data->full);
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ui_data->menu_full), !ui_data->full);
     }
 
     /* handling window state */
@@ -71,7 +71,7 @@ void callback_tool_full(GtkAction* action, gpointer data)
 /* CALLBACK TOOLBAR */
 void callback_tool_tool(GtkAction* action, gpointer data)
 {
-    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(ui_data->menu_tool), !ui_data->tool);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ui_data->menu_tool), !ui_data->tool);
 }
 
 /**
@@ -115,6 +115,17 @@ void callback_goto(GtkWidget* widget, int i)
     }
 }
 
+/**
+ * @brief about window callback
+ * @param
+ * @return
+**/
+void callback_bout(GtkAction* action, gpointer data)
+{
+    ui_init_bout();
+    gtk_widget_show(GTK_WIDGET(ui_data->window_bout));
+}
+
 /**
  * @brief help window callback
  * @param
@@ -848,12 +859,12 @@ void ui_init_friend_profile(GtkWidget* container, gpointer ptr_str_id)
     int i = 0;
     GtkWidget* box_service = gtk_hbox_new(FALSE, 0);
     GList* node;
-    msa_driver_info* info;
+    msa_module* info;
     GtkWidget* icon_service[ui_data->num_srvs];
     GtkWidget* alignment[ui_data->num_srvs];
     GtkWidget* combo = gtk_combo_box_new_text();
     for(node = ui_data->drivers; node != NULL; node = node->next) {
-        info = (msa_driver_info*)node->data;
+        info = (msa_module*)node->data;
         if (info->pic == NULL){
             icon_service[i] = gtk_image_new_from_file(IMG_SRVC);
         } else {
@@ -1000,10 +1011,10 @@ void callback_friends_join(GtkWidget* button_cb, gpointer data)
     //FIXME
     
     GList* node;
-    msa_driver_info* info;
+    msa_module* info;
     int size;
     for(node = ui_data->drivers; node != NULL; node = node->next) {
-        info = (msa_driver_info*)node->data;
+        info = (msa_module*)node->data;
         str_serv = g_strdup(info->name); 
         if (info->pic != NULL){
             str_icon = g_base64_decode((gchar*)info->pic, &size);
@@ -1315,10 +1326,10 @@ void callback_button_setup_service(GtkWidget* button, int id_service)
     
     GList* node;
     int i = 0;
-    msa_driver_info* info;
+    msa_module* info;
     for(node = ui_data->drivers; node != NULL; node = node->next) {
         if (i == id_service){
-            info = (msa_driver_info*)node->data;
+            info = (msa_module*)node->data;
                         
             g_debug("callback_get_settings: driver status = %d state = %d", info->status, info->state);
 
@@ -1398,11 +1409,11 @@ void callback_button_save_setup_service(GtkWidget* button, gpointer id)
     
     GList* node;
     int i = 0;
-    msa_driver_info* info;
+    msa_module* info;
     
     for(node = ui_data->drivers; node != NULL; node = node->next) {
         if (i == ui_data->srvc){
-            info = (msa_driver_info*)node->data;
+            info = (msa_module*)node->data;
             char* actv;
             if (gtk_toggle_button_get_active(ui_data->entry_actv)){
                 actv = g_strdup("1");
