@@ -30,10 +30,10 @@
 void ui_init()
 {
     HildonProgram* program;
-    HildonWindow* window;
+    GtkWidget* window;
 
     program = HILDON_PROGRAM(hildon_program_get_instance());
-    window  = HILDON_WINDOW(hildon_window_new());
+    window = hildon_stackable_window_new ();
     
     /* window */
     ui_data->program = HILDON_PROGRAM(program);
@@ -60,10 +60,10 @@ void ui_init()
     ui_init_tools();
     ui_init_menus();
 
-    hildon_program_add_window(program, window);
+    //hildon_program_add_window(program, window);
     g_set_application_name(STR_PROG);
     gtk_window_set_title (GTK_WINDOW (ui_data->window), ui_data->str_page[0]);
-    gtk_widget_show(GTK_WIDGET(program));
+    gtk_widget_show(window);
     //gtk_main();
 }
 
@@ -118,7 +118,7 @@ static void ui_init_page0()
     GtkWidget* label0 = gtk_label_new(STR_SETP);
     GtkWidget* label1 = gtk_label_new(STR_THEN);
     GtkWidget* image = gtk_image_new_from_file(IMG_MYSC);
-    GtkWidget* button = gtk_button_new_with_label(STR_GO__);
+    GtkWidget* button =  hildon_button_new_with_text (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_AUTO_HEIGHT, NULL, STR_GO__, NULL);
     //smy_widget_init(button);
     
     GtkWidget* alignment_label0 = gtk_alignment_new(0, 0.5, 0, 0);
@@ -230,9 +230,9 @@ static void ui_init_page1()
     labels[2] = gtk_label_new(NULL);
     labels[3] = gtk_label_new(NULL);
 
-    gchar* strings = g_strdup(g_strconcat(MARKUP, "Login:", PUKRAM, NULL));
+    gchar* strings = g_strdup(g_strconcat(MARKUP, _("Login:"), PUKRAM, NULL));
     gtk_label_set_markup (labels[0], strings);
-    strings = g_strdup(g_strconcat(MARKUP, "Password:", PUKRAM, NULL));
+    strings = g_strdup(g_strconcat(MARKUP, _("Password:"), PUKRAM, NULL));
     gtk_label_set_markup (labels[1], strings);
     strings = g_strdup(g_strconcat(MARKUP, "Auto-update time:", PUKRAM, NULL));
     gtk_label_set_markup (labels[2], strings);
@@ -244,10 +244,10 @@ static void ui_init_page1()
     gtk_box_pack_start (GTK_BOX (hbox[2]), labels[2], TRUE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (hbox[3]), labels[3], TRUE, TRUE, 0);
     
-    ui_data->entry_logn = gtk_entry_new();
-    ui_data->entry_pass = gtk_entry_new();
+    ui_data->entry_logn = hildon_entry_new (HILDON_SIZE_THUMB_HEIGHT);
+    ui_data->entry_pass = hildon_entry_new (HILDON_SIZE_THUMB_HEIGHT);
     gtk_entry_set_visibility(GTK_ENTRY(ui_data->entry_pass), FALSE);
-    ui_data->entry_auto = gtk_entry_new();
+    ui_data->entry_auto = hildon_entry_new (HILDON_SIZE_THUMB_HEIGHT);
     ui_data->entry_actv = gtk_check_button_new();
     gtk_widget_set_sensitive(GTK_WIDGET(ui_data->entry_actv), FALSE);
     gtk_widget_set_usize (ui_data->entry_logn, -1, MIN_HEIGHT);
@@ -310,12 +310,12 @@ static void ui_init_page2()
     
     /* ICONS OF SERVICES */
     GList* node;
-    msa_driver_info* info;
+    msa_module* info;
     GtkWidget* icon_service[ui_data->num_srvs];
     GtkWidget* alignment[ui_data->num_srvs];
     GtkWidget* combo = gtk_combo_box_new_text();
     for(node = ui_data->drivers; node != NULL; node = node->next) {
-        info = (msa_driver_info*)node->data;
+        info = (msa_module*)node->data;
         if (info->pic == NULL){
             icon_service[i] = gtk_image_new_from_file(IMG_SRVC);
         } else {
@@ -625,7 +625,7 @@ static gpointer ui_init_list_drivers()
     GtkWidget* scrollable = gtk_scrolled_window_new(NULL, NULL); 
     ui_data->list_drvs = scrollable;
     GList* node;
-    msa_driver_info* info;
+    msa_module* info;
     
     GtkWidget* alignment_list = gtk_alignment_new (0.5, 0.5, 1, 1);
     gtk_alignment_set_padding (GTK_ALIGNMENT(alignment_list), 0, 0, 0, PADDING);
@@ -641,7 +641,7 @@ static gpointer ui_init_list_drivers()
     /* LIST ELEMENTS */
     for(node = ui_data->drivers; node != NULL; node = node->next) {
         //for (i = 0; i < ui_data->num_srvs; i++) {
-        info = (msa_driver_info*)node->data;
+        info = (msa_module*)node->data;
         //sprintf(strings, "service %d", i + 1);
         label_service = gtk_label_new(info->name); 
 
@@ -771,14 +771,15 @@ static void ui_init_menus()
 {
     //UIdata*    ui_data = ui_data_ptr;
     /* Create needed handles */
-    GtkMenu*   main_menu;
+    HildonAppMenu* main_menu;
     GtkWidget* extra_menu;
     GtkWidget* separator = NULL;
     GtkWidget* help  = NULL;
+    GtkWidget* bout = NULL;
     GtkWidget* close = NULL;
 
     /* Create menu and new menu for submenu in drop down menu */
-    main_menu  = GTK_MENU(gtk_menu_new());
+    main_menu  = HILDON_APP_MENU(hildon_app_menu_new());
     extra_menu = gtk_menu_new();
 
     /* Create the menu items */
@@ -792,11 +793,18 @@ static void ui_init_menus()
     //ui_data->copy_item   = gtk_menu_item_new_with_label("Copy");
     //ui_data->paste_item  = gtk_menu_item_new_with_label("Paste");
 
-    ui_data->menu_full = gtk_check_menu_item_new_with_label(STR_FULL);
-    ui_data->menu_tool = gtk_check_menu_item_new_with_label(STR_TOOL);
-    separator          = gtk_separator_menu_item_new();
-    ui_data->menu_help = gtk_menu_item_new_with_label(STR_HELP);
-    ui_data->menu_exit = gtk_menu_item_new_with_label(STR_EXIT);
+    ui_data->menu_full = hildon_gtk_toggle_button_new (HILDON_SIZE_AUTO);
+    gtk_button_set_label(GTK_BUTTON(ui_data->menu_full), STR_FULL);
+
+    ui_data->menu_tool = hildon_gtk_toggle_button_new  (HILDON_SIZE_AUTO);
+    gtk_button_set_label(GTK_BUTTON(ui_data->menu_tool), STR_TOOL);
+    //separator          = gtk_separator_menu_item_new();
+    ui_data->menu_help = hildon_gtk_button_new(HILDON_SIZE_AUTO);
+    gtk_button_set_label(GTK_BUTTON(ui_data->menu_help), STR_HELP);
+    bout = hildon_gtk_button_new(HILDON_SIZE_AUTO);
+    gtk_button_set_label(GTK_BUTTON(bout), STR_BOUT);
+    ui_data->menu_exit = hildon_gtk_button_new(HILDON_SIZE_AUTO);
+    gtk_button_set_label(GTK_BUTTON(ui_data->menu_exit), STR_EXIT);
 
     /* Add menu items to right menus */
     //gtk_menu_append( main_menu, ui_data->file_item );
@@ -810,23 +818,26 @@ static void ui_init_menus()
     //gtk_menu_append( main_menu, ui_data->sendvia_item );
 
     //gtk_menu_append( main_menu, ui_data->font_item );
-    gtk_menu_append(main_menu, ui_data->menu_full);
-    gtk_menu_append(main_menu, ui_data->menu_tool);
-    gtk_menu_append(main_menu, separator);
-    gtk_menu_append(main_menu, ui_data->menu_help);
-    gtk_menu_append(main_menu, ui_data->menu_exit);
+    hildon_app_menu_append(main_menu, ui_data->menu_full);
+    hildon_app_menu_append(main_menu, ui_data->menu_tool);
+    //hildon_app_menu_append(main_menu, separator);
+    hildon_app_menu_append(main_menu, bout);
+    hildon_app_menu_append(main_menu, ui_data->menu_help);
+    hildon_app_menu_append(main_menu, ui_data->menu_exit);
 
     /* Add submenus to the right items */
     //gtk_menu_item_set_submenu(GTK_MENU_ITEM(ui_data->file_item), extra_menu);
 
     /* Attach the callback functions to the activate signal */
-    g_signal_connect(G_OBJECT(ui_data->menu_full), "activate", G_CALLBACK(callback_full), NULL);
-    g_signal_connect(G_OBJECT(ui_data->menu_tool), "activate", G_CALLBACK(callback_tool), NULL);
-    g_signal_connect(G_OBJECT(ui_data->menu_help), "activate", G_CALLBACK(callback_help), NULL);
-    g_signal_connect(G_OBJECT(ui_data->menu_exit), "activate", G_CALLBACK(callback_exit), NULL);
+    g_signal_connect_after(G_OBJECT(ui_data->menu_full), "clicked", G_CALLBACK(callback_full), NULL);
+    g_signal_connect_after(G_OBJECT(ui_data->menu_tool), "clicked", G_CALLBACK(callback_tool), NULL);
+    g_signal_connect_after(G_OBJECT(ui_data->menu_help), "clicked", G_CALLBACK(callback_help), NULL);
+    g_signal_connect_after(G_OBJECT(bout), "clicked", G_CALLBACK(callback_bout), NULL);
+    g_signal_connect_after(G_OBJECT(ui_data->menu_exit), "clicked", G_CALLBACK(callback_exit), NULL);
 
     /* Add menu to HildonWindow */
-    hildon_window_set_menu(ui_data->window, main_menu);
+    hildon_stackable_window_set_main_menu (ui_data->window, main_menu);
+    //hildon_window_set_app_menu(ui_data->window, main_menu);
 
     /* We need to show menu items */
     gtk_widget_show_all(GTK_WIDGET(main_menu));
@@ -841,9 +852,9 @@ static void ui_init_menus()
 void ui_init_help()
 {
     //UIdata*    ui_data = ui_data_ptr;
-    HildonWindow* window_help;
-    window_help = HILDON_WINDOW(hildon_window_new());
-    hildon_program_add_window(ui_data->program, window_help);
+    GtkWidget* window_help;
+    window_help = hildon_stackable_window_new();;
+    //hildon_program_add_window(ui_data->program, window_help);
     gtk_window_set_title (GTK_WINDOW (window_help), STR_HELP);
     ui_data->window_help = HILDON_WINDOW(window_help);
     //g_print("in ui_init_help: help is %d\n", ui_data->help);
@@ -865,7 +876,7 @@ void ui_init_help()
             //}
 	//}
             GtkWidget* label;
-            label = gtk_label_new(STR_ABOUT);
+            label = gtk_label_new(STR_HELPT);
             GtkWidget* box = gtk_vbox_new(TRUE, 0);
 	    gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
 	    gtk_label_set_single_line_mode(GTK_LABEL(label), FALSE);
@@ -879,3 +890,48 @@ void ui_init_help()
     //}    
 }
 
+/**
+ * @brief help
+ * @param
+ * @return  
+**/
+void ui_init_bout()
+{
+    //UIdata*    ui_data = ui_data_ptr;
+    GtkWidget* window_bout;
+    window_bout = hildon_stackable_window_new();
+    //hildon_program_add_window(ui_data->program, window_bout);
+    gtk_window_set_title (GTK_WINDOW (window_bout), STR_BOUT);
+    ui_data->window_bout = HILDON_WINDOW(window_bout);
+    //g_print("in ui_init_help: help is %d\n", ui_data->help);
+    //ui_data->help = TRUE;
+    //g_signal_connect(G_OBJECT(window_help), "destroy", G_CALLBACK(callback_help_close), NULL);
+    
+    //FILE* cap_fp;
+    //char* new_line;
+    //char* cap_string = g_strdup("");
+    //int cap_limit = SIZE_HELP;
+    /* Check whether the file being opened exists */
+    //if ((cap_fp = fopen (TXT_HELP, "r")) != NULL){
+        /* Check whether the string was read */
+        //while (fgets (new_line, cap_limit, cap_fp) != NULL) {
+            //cap_string = g_strdup(g_strconcat(cap_string, new_line, NULL));
+	    /* Strip the newline if needed */
+            //if ((newline = strrchr (cap_string, '\n')) != NULL) {
+            //    *newline = '\0';
+            //}
+	//}
+            GtkWidget* label;
+            label = gtk_label_new(STR_ABOUT);
+            GtkWidget* box = gtk_vbox_new(TRUE, 0);
+	    gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
+	    gtk_label_set_single_line_mode(GTK_LABEL(label), FALSE);
+            gtk_box_pack_start (GTK_BOX (box), label, FALSE, FALSE, 0);
+            gtk_container_add(GTK_CONTAINER((GtkWidget*)ui_data->window_bout), box);
+            gtk_widget_show_all((GtkWidget*)ui_data->window_bout);
+            //g_print(cap_string);
+            return;
+        
+        //g_print("file is read\n");
+    //}    
+}
